@@ -6,6 +6,7 @@ import os
 import signal
 import sys
 import time
+from typing import Any
 
 from ivy.std_api import *
 
@@ -14,43 +15,46 @@ try:
 except ImportError:
     pass
 
-# The next line taken from https://pythonhosted.org/six/
-# Copyright (c) 2010-2016 Benjamin Peterson
-PY2 = sys.version_info[0] == 2
-
 
 IVYAPPNAME = 'pyivyprobe'
 
 on_die_accepted = False
 
-def info(fmt, *arg):
+
+def info(fmt: str, *arg: Any) -> None:
     print(fmt % arg)
 
 
-def usage(cmd):
+def usage(cmd: str) -> None:
     usage = '''Usage: %s [options] regexps
 Options:
 \t-b, --ivybus=bus    defines the Ivy bus to join; defaults to 127:2010
 \t-h, --help          this message
-\t-n, --name=<name>   changes the name of the agent, defaults to %s
+\t-n, --name=<name>   changes the name of the agent, defaults to: '%s'
+\t-r, --ready=<msg>   sets the ready message (use the empty string to disable it)
+\t                    default is: '%s'
 \t-s, --show-bindings show changes in other agents' bindings
 \t-V, --version       prints the ivy release number
 \t-v, --verbose       verbose mode (twice makes it even more verbose)
 
 Type '.help' in ivyprobe for a list of available commands.'''
-    print(usage % (os.path.basename(cmd), IVYAPPNAME))
+    print(usage % (os.path.basename(cmd), IVYAPPNAME, f"{IVYAPPNAME} Ready"))
 
 
-def on_connection_change(agent, event):
+def on_connection_change(agent: IvyClient, event: int) -> None:
     if event == IvyApplicationDisconnected:
         info('Ivy application %r has disconnected', agent)
     else:
         info('Ivy application %r has connected', agent)
-    info('Ivy applications currently on the bus: %s',
-         ','.join(IvyGetApplicationList()))
+    apps = IvyGetApplicationList()
+    info(
+        'Ivy applications currently on the bus (count: %i): %s',
+        len(apps),
+        ','.join(apps),
+    )
 
 
-def on_die(agent, _id):
+def on_die(agent: IvyClient, _id: int) -> None:
     info('Received the order to die from %r with id = %d', agent, _id)
     global on_die_accepted
     on_die_accepted = True
@@ -58,27 +62,31 @@ def on_die(agent, _id):
     os.kill(os.getpid(), signal.SIGINT)
 
 
-def on_msg(agent, *arg):
-    info('Received from %r: %s', agent, arg and str(arg) or '<no args>')
+def on_msg(agent: IvyClient, *arg: Any) -> None:
+    info('Received from %r: %r', agent, arg and arg or '<no args>')
 
 
-def on_direct_msg(agent, num_id, msg):
-    info('%r sent a direct message, id=%s, message=%s',
-         agent, num_id, msg)
+def on_direct_msg(agent: IvyClient, num_id: int, msg: str) -> None:
+    info('%r sent a direct message, id=%s, message=%r', agent, num_id, msg)
 
 
-def on_regexp_change(agent, event, regexp_id, regexp):
+def on_regexp_change(agent: IvyClient, event: int, regexp_id: int, regexp: str) -> None:
     from ivy.ivy import IvyRegexpAdded
-    info('%r %s regexp id=%s: %s',
-         agent, event == IvyRegexpAdded and 'added' or 'removed',
-         regexp_id, regexp)
+
+    info(
+        '%r %s regexp id=%s: %r',
+        agent,
+        event == IvyRegexpAdded and 'added' or 'removed',
+        regexp_id,
+        regexp,
+    )
 
 
-def on_pong(agent, delta):
+def on_pong(agent: IvyClient, delta: float) -> None:
     info('%s answered to ping in %fs', agent, delta)
 
 
-def _set_showbind(showbind):
+def _set_showbind(showbind: bool) -> None:
     if showbind:
         IvyBindRegexpChange(on_regexp_change)
         info("Changes in applications' bindings are shown")
@@ -88,11 +96,12 @@ def _set_showbind(showbind):
 
 
 if __name__ == '__main__':
-    from ivy.ivy import ivylogger
     import logging
 
+    from ivy.ivy import ivylogger
+
     ivybus = ''
-    readymsg = '[%s is ready]' % IVYAPPNAME
+    readymsg = None
     verbose = 0
     showbind = False
     toggle_showbind = False
@@ -100,11 +109,11 @@ if __name__ == '__main__':
     ivylogger.setLevel(logging.WARN)
 
     try:
-        optlist, left_args = \
-            getopt.getopt(sys.argv[1:],
-                          'hb:n:Vvs',
-                          ['help', 'ivybus=', 'name=', 'version', 'verbose',
-                           'show-bindings'])
+        optlist, left_args = getopt.getopt(
+            sys.argv[1:],
+            'hb:n:r:Vvs',
+            ['help', 'ivybus=', 'name=', 'ready=', 'version', 'verbose', 'show-bindings'],
+        )
     except getopt.GetoptError:
         usage(sys.argv[0])
         sys.exit(2)
@@ -116,8 +125,8 @@ if __name__ == '__main__':
             ivybus = arg
         elif opt in ('-V', '--version'):
             import ivy
-            info('ivyprobe supplied with ivy-python library version%s',
-                 ivy.__version__)
+
+            info('ivyprobe supplied with ivy-python library version%s', ivy.__version__)
             sys.exit()
         elif opt in ('-v', '--verbose'):
             if not verbose:
@@ -131,18 +140,24 @@ if __name__ == '__main__':
                     ivylogger.setLevel(logging.TRACE)
         elif opt in ('-n', '--name'):
             IVYAPPNAME = arg
+        elif opt in ('-r', '--ready'):
+            readymsg = arg
         elif opt in ('-s', '--showbind'):
             showbind = True
 
-    info('Broadcasting on %s',
-         ivybus or os.environ.get('IVYBUS') or 'ivydefault')
+    if readymsg is None:
+        readymsg = '%s Ready' % IVYAPPNAME
+
+    info('Broadcasting on %s', ivybus or os.environ.get('IVYBUS') or 'ivydefault')
 
     # initialising the bus
-    IvyInit(IVYAPPNAME,             # application name for Ivy
-            readymsg,               # ready message
-            0,                      # parameter ignored
-            on_connection_change,   # handler called on connection/disconnection
-            on_die)                 # handler called when a die msg is received
+    IvyInit(
+        IVYAPPNAME,            # application name for Ivy
+        readymsg,              # ready message
+        0,                     # parameter ignored
+        on_connection_change,  # handler called on connection/disconnection
+        on_die,                # handler called when a die msg is received
+    )
 
     _set_showbind(showbind)
 
@@ -163,27 +178,24 @@ if __name__ == '__main__':
     time.sleep(0.5)
     info('Go ahead! (type .help for help on commands)')
     while 1:
-
         if toggle_showbind:
             toggle_showbind = False
             showbind = not showbind
             _set_showbind(showbind)
 
         try:
-            if PY2:
-                msg = raw_input('')
-            else:
-                msg = input('')
+            msg = input('')
 
         except (EOFError, KeyboardInterrupt):
             msg = '.quit'
 
         if msg == '.help':
-            info("""Available commands:
+            info(
+                """Available commands:
         .bind 'regexp'              - add a msg to receive. The displayed index
                                                      can be supplied to .remove
         .die appname                - send die msg to appname
-        .dieall-yes-i-am-sure       - send die msg to all applications
+        .die-all-yes-i-am-sure      - send die msg to all applications
         .direct appname id arg      - send direct msg to appname
         .help                       - print this message
         .error appname id err_msg   - send an error msg to an appname
@@ -197,8 +209,10 @@ if __name__ == '__main__':
         .who                        - display the names of all applications on
                                                                        the bus
 
-Everything that is not a (valid) command is interpreted as a message and sent to the appropriate applications on the bus.
-""")
+Everything that is not a (valid) command is interpreted as a message and sent
+to the appropriate applications on the bus.
+"""
+            )
 
         elif msg[:5] == '.bind':
             regexp = msg[6:]
@@ -215,7 +229,7 @@ Everything that is not a (valid) command is interpreted as a message and sent to
             for app_name in IvyGetApplicationList():
                 app = IvyGetApplication(app_name)
                 if not app:
-                    info('No application %s' % app_name)
+                    info('No application %r' % app_name)
                 else:
                     IvySendDieMsg(app)
 
@@ -223,40 +237,43 @@ Everything that is not a (valid) command is interpreted as a message and sent to
             app_name = msg[5:]
             app = IvyGetApplication(app_name)
             if app is None:
-                info('No application named %s', app_name)
+                info('No application named %r', app_name)
                 continue
             IvySendDieMsg(app)
 
         elif msg[:7] == '.direct':
             try:
-                app_name, num = msg[8:].split()[:2]
-                arg = ' '.join(msg[8:].split()[2:])
-                if not arg:
-                    raise ValueError
+                app_name, num_s, arg = msg[8:].split(' ', 2)
             except ValueError:
                 print('Error: wrong number of parameters')
                 continue
-
+            try:
+                num = int(num_s)
+            except ValueError:
+                print('Error: the id must be an integer')
+                continue
             app = IvyGetApplication(app_name)
             if app is None:
-                info('No application named %s', app_name)
+                info('No application named %r', app_name)
                 continue
 
             IvySendDirectMsg(app, num, arg)
 
         elif msg[:6] == '.error':
             try:
-                app_name, num = msg[7:].split()[:2]
-                err_msg = ' '.join(msg[7:].split()[2:])
-                if not err_msg:
-                    raise ValueError
+                app_name, num_s, err_msg = msg[7:].split(' ', 2)
             except ValueError:
                 print('Error: wrong number of parameters')
                 continue
+            try:
+                num = int(num_s)
+            except ValueError:
+                print('Error: the id must be an integer')
+                continue
 
             app = IvyGetApplication(app_name)
             if app is None:
-                info('No application named %s', app_name)
+                info('No application named %r', app_name)
                 continue
 
             IvySendError(app, num, err_msg)
@@ -264,7 +281,7 @@ Everything that is not a (valid) command is interpreted as a message and sent to
         elif msg[:7] == '.remove':
             try:
                 regexp_id = int(msg[8:])
-                info('Removed %d:%s', regexp_id, IvyUnbindMsg(regexp_id))
+                info('Removed %d:%r', regexp_id, IvyUnbindMsg(regexp_id))
             except KeyError:
                 info('No such binding')
             except ValueError:
@@ -274,7 +291,7 @@ Everything that is not a (valid) command is interpreted as a message and sent to
             app_name = msg[6:]
             app = IvyGetApplication(app_name)
             if app is None:
-                info("No application named '%s'", app_name)
+                info("No application named %r", app_name)
                 continue
             IvySendPing(app)
             info('Sent PING')
@@ -282,17 +299,32 @@ Everything that is not a (valid) command is interpreted as a message and sent to
         elif msg == '.regexps':
             from ivy import std_api
 
-            info('Our subscriptions: %s',
-                 ', '.join(["%s:'%s'" % (_id, regexp) for _id, regexp in std_api._IvyServer.get_subscriptions()]))
+            info(
+                'Our subscriptions: %s',
+                ', '.join(
+                    [
+                        "%s:'%s'" % (_id, regexp)
+                        for _id, regexp in IvyGetMessages()
+                    ]
+                ),
+            )
 
         elif msg[:9] == '.regexps ':
             app_name = msg[9:]
             app = IvyGetApplication(app_name)
             if app is None:
-                info("Error: no application found with name '%s'"%app_name)
+                info("Error: no application found with name %r" % app_name)
             else:
-                info('Subscriptions for %s: %s',
-                     app_name, ', '.join(["%s:'%s'" % (_id, regexp) for _id, regexp in IvyGetApplicationMessages(app)]))
+                info(
+                    'Subscriptions of %r: %s',
+                    app_name,
+                    ', '.join(
+                        [
+                            "%s:'%s'" % (_id, regexp)
+                            for _id, regexp in IvyGetApplicationMessages(app)
+                        ]
+                    ),
+                )
 
         elif msg[:9] == '.showbind':
             toggle_showbind = True
@@ -308,9 +340,9 @@ Everything that is not a (valid) command is interpreted as a message and sent to
             app_name = msg[7:]
             app = IvyGetApplication(app_name)
             if app is None:
-                info('No application named %s', app)
+                info('No application named %r', app)
                 continue
-            info('Application %s on %s:%s', app_name, app.ip, app.port)
+            info('Application %r on %s:%s', app_name, app.ip, app.port)
 
         elif msg == '.who':
             print(IvyGetApplicationList())
