@@ -6,11 +6,6 @@ subscription mechanism based on regular expressions.
 If you're used to the standard Ivy API, you probably want to look at the
 `std_api` module.
 
-.. note:: Version 2.0 broke backward compatibility.  If you are upgrading
-   from ivy-python v1.x, be sure to read the `v2.0 compatibility notes`_,
-   below.
-
-
 For an introduction of the package, see the :doc:`overview` and the :doc:`tutorial`..
 
 
@@ -20,7 +15,8 @@ Understanding the package
 This Ivy package is made of two modules: :py:mod:`ivy.std_api` and :py:mod:`ivy.ivy`.
 
 In order to understand the way it works, we highly suggest that you read the
-materials available from the `Ivy Home Page`_ in addition to our tutorial.  Within the documentation of
+materials available from the `Ivy Home Page`_ in addition to our tutorial.
+Within the documentation of
 this python package we suppose that you are already familiar with the way an
 ivy bus works, and with how the corresponding framework is organized.
 
@@ -41,12 +37,10 @@ is included with the package, see ``examples/pyhello.py``.
 :py:mod:`ivy.ivy`
 ~~~~~~~~~~~~~~~~~
 
-It's where the "magic" goes: the module `std_api` is built on top of it.
+It's where the logic is implemented: the module `std_api` is built on top of it.
 
-You'll be interested in using this package if for example, you want to manage
-more than one ivy-bus in an application.  We won't give here much hint on how
-to use it, since the code of the `ivy` module itself serves as a perfect
-example of use!
+This package allows to manage more than one ivy bus in an application.
+Refer to the implementation of the `ivy` module for an example of how to use it.
 
 Logging
 -------
@@ -69,53 +63,13 @@ Logging
   Further details can be found in the `Python standard documentation
   <http://docs.python.org/lib/module-logging.html>`_.
 
-v2.0 compatibility notes
-------------------------
 
-Version 2.0 broke the backward compatibility with former versions 1.x: every
-callback methods now receives an `ivy.IvyClient` object as its first
-parameter.
+Supported python
+----------------
 
-This makes it possible for the receiving code to know which agent on the bus
-sends the corresponding event. Unfortunately, this breaks backward
-compatibility and callback methods must be adapted to the new scheme.
-
-For example, suppose you're binding a regexp to the callback ``on_msg``:
-
-.. code:: python
-
-  IvyBindMsg(onhello, "^hello=([^ ]*) from=([^ ]*)")
-
-In ivy-python 1.x, you used to declare the callback as follows:
-
-.. code:: python
-
-      def onhello(*arg):
-          print "Got hello message: %s from: %s"% (arg[0], arg[1])
-
-or:
-
-.. code:: python
-
-      def onhello(message, from):
-          print "Got hello message: %s from: %s"% (message, from)
-
-
-In version 2.0, your callbacks also get the agent triggering the event as the
-1st parameter; the previous callbacks should be rewritten this way:
-
-.. code:: python
-
-      def onhello(*arg):
-          print "Got hello message: %s from: %s (coming from ivy agent: %r)"% (arg[1], arg[2], arg[0])
-
-or:
-
-.. code:: python
-
-      def onhello(agent, message, from):
-          print "Got hello message: %s from: %s (coming from ivy agent: %r)"% (message, from, agent)
+Python 3.7 or higher is needed.
 
+.. note:: ivy-python v3.3 was the last one supporting Python 2.7.
 
 Misc. notes
 -----------
@@ -137,10 +91,10 @@ This software is distributed under the `"new" BSD license
 
 (please refer the file ``LICENSE`` for full legal details)
 
-Copyright (c) 2005-2021 Sebastien Bigaret <sebastien.bigaret@telecom-bretagne.eu>
+Copyright (c) 2005-2023 Sebastien Bigaret <sebastien.bigaret@telecom-bretagne.eu>
 
 .. _Ivy Home Page: http://www.eei.cena.fr/products/ivy/
 .. _The Ivy C library: http://www.eei.cena.fr/products/ivy/documentation/ivy-c.pdf
 .. _Ivy downloads page: http://www.eei.cena.fr/products/ivy/download/binaries.html
 """
-__version__ = '3.1'
+__version__ = '4.0'
